<?php

namespace Drupal\synapse\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements the form controller.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'synapse_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['synapse.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('synapse.settings');

    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('General settings'),
      '#open' => TRUE,
    ];

    $form['general']['gtm_id'] = [
      '#title' => $this->t('GTM-ID'),
      '#default_value' => $config->get('gtm-id'),
      '#maxlength' => 20,
      '#size' => 15,
      '#type' => 'textfield',
      '#description' => $this->t('You can add site to
        <a target="_blank" href="https://tagmanager.google.com/?hl=ru" title="Metrica add">Google Tag Manager</a>'),
    ];
    $form['general']['webmaster_yandex'] = [
      '#title' => $this->t('Yandex Webmaster'),
      '#default_value' => $config->get('wm-yandex'),
      '#maxlength' => 255,
      '#size' => 80,
      '#type' => 'textfield',
      '#description' => $this->t('«meta name="yandex-verification" content="<strong>__THIS_CODE__</strong>" /»)<br />
        You can add site to Yandex webmaster
        <a target="_blank" href="http://webmaster.yandex.ru/site/add.xml" title="Metrica add">here</a>'),
    ];
    $form['general']['webmaster_google'] = [
      '#title' => $this->t('Google Webmaster'),
      '#default_value' => $config->get('wm-google'),
      '#maxlength' => 255,
      '#size' => 80,
      '#type' => 'textfield',
      '#description' => $this->t('«meta name="google-site-verification" content="<strong>__THIS_CODE__</strong>" /»)<br />
        You can add site to Google webmaster
        <a target="_blank" href="https://www.google.com/webmasters/tools/home?hl=ru" title="Metrica add">here</a>'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('synapse.settings');
    $config
      ->set('gtm-id', $form_state->getValue('gtm_id'))
      ->set('wm-yandex', $form_state->getValue('webmaster_yandex'))
      ->set('wm-google', $form_state->getValue('webmaster_google'))
      ->save();
  }

}
